@@ -1,5 +1,9 @@
 {-# LANGUAGE CPP #-}
 
+#if __GLASGOW_HASKELL__ >= 702
+{-# LANGUAGE Safe #-}
+#endif
+
 #ifndef MIN_VERSION_semigroups
 #define MIN_VERSION_semigroups(x,y,z) 0
 #endif
@@ -26,12 +30,14 @@ module Data.Biapplicative (
 import Control.Applicative
 import Data.Bifunctor
 
-#if MIN_VERSION_semigroups(0,16,2)
-import Data.Semigroup
-#else
+#if !(MIN_VERSION_base(4,8,0))
 import Data.Monoid
 #endif
 
+#if MIN_VERSION_base(4,9,0) || MIN_VERSION_semigroups(0,16,2)
+import Data.Semigroup (Arg(..))
+#endif
+
 #ifdef MIN_VERSION_tagged
 import Data.Tagged
 #endif
@@ -82,7 +88,7 @@ instance Biapplicative (,) where
   (f, g) <<*>> (a, b) = (f a, g b)
   {-# INLINE (<<*>>) #-}
 
-#if MIN_VERSION_semigroups(0,16,2)
+#if MIN_VERSION_base(4,9,0) || MIN_VERSION_semigroups(0,16,2)
 instance Biapplicative Arg where
   bipure = Arg
   {-# INLINE bipure #-}
