@@ -592,6 +592,9 @@ pureValName = mkNameG_v "base" "GHC.Base" "pure"
 apValName :: Name
 apValName = mkNameG_v "base" "GHC.Base" "<*>"
 
+liftA2ValName :: Name
+liftA2ValName = mkNameG_v "base" "GHC.Base" "liftA2"
+
 mappendValName :: Name
 mappendValName = mkNameG_v "base" "GHC.Base" "mappend"
 
@@ -610,6 +613,9 @@ pureValName = mkNameG_v "base" "Control.Applicative" "pure"
 apValName :: Name
 apValName = mkNameG_v "base" "Control.Applicative" "<*>"
 
+liftA2ValName :: Name
+liftA2ValName = mkNameG_v "base" "Control.Applicative" "liftA2"
+
 mappendValName :: Name
 mappendValName = mkNameG_v "base" "Data.Monoid" "mappend"
 
@@ -617,7 +623,7 @@ memptyValName :: Name
 memptyValName = mkNameG_v "base" "Data.Monoid" "mempty"
 #endif
 
-#if __GLASGOW_HASKELL__ >= 801
+#if MIN_VERSION_base(4,10,0)
 bifoldableTypeName :: Name
 bifoldableTypeName = mkNameG_tc "base" "Data.Bifoldable" "Bifoldable"
 
